# -*- coding: utf-8 -*- 
"""
@User     : Frank
@File     : __init__.py
@DateTime : 2019-09-16 11:40 
@Email    : frank.chang@lexisnexis.com
"""

__name__ = 'useful_decoration'
__version__ = '1.0.6'
__author__ = 'frank'

if __name__ == '__main__':
    pass
